@@ -74,7 +74,7 @@ def get_project_path(proj_name):
         proj_path = get_datadir()
     else:
         base_path = get_base_path()
-        proj_path = os.path.join(base_path, 'project', proj_name)
+        proj_path = os.path.join(base_path, 'projects', proj_name)
     if not os.path.exists(proj_path):
         raise RuntimeError('Project "{}" not found.'.format(proj_name))
     return proj_path
